@@ -20,9 +20,6 @@
 #ifndef APPDATA_H
 #define APPDATA_H
 
-/* this define will enable preliminary API 0.6 support */
-#define API06
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -153,13 +150,13 @@ typedef struct appdata_s {
 
 } appdata_t;
 
+#include "settings.h"
 #include "map.h"
 #include "map_hl.h"
 #include "osm_api.h"
 #include "statusbar.h"
 #include "area_edit.h"
 #include "project.h"
-#include "settings.h"
 #include "diff.h"
 #include "iconbar.h"
 #include "icon.h"
