@@ -27,7 +27,20 @@
 #define OSM_FLAG_NEW      (1<<2)
 #define OSM_FLAG_HIDDEN   (1<<3)
 
-typedef gulong item_id_t;
+/* item_id_t needs to be signed as osm2go uses negative ids for items */
+/* not yet registered with the main osm database */
+#if 1
+/* currently 31 bit is still sufficient since there are less than */
+/* 2 billion nodes or changesets */
+typedef gint32 item_id_t;
+#define G_TYPE_ITEM_ID_T G_TYPE_INT
+#define ITEM_ID_FORMAT  "%" G_GINT32_FORMAT
+#else
+/* the future may require us to switch to 64 bits */
+typedef gint64 item_id_t;
+#define G_TYPE_ITEM_ID_T G_TYPE_INT64
+#define ITEM_ID_FORMAT  "%" G_GINT64_FORMAT
+#endif
 
 #define ID_ILLEGAL  ((item_id_t)0)
 
@@ -53,6 +66,7 @@ typedef struct tag_s {
 
 typedef struct node_s {
   item_id_t id;
+  item_id_t version;
   pos_t pos;
   lpos_t lpos;
   user_t *user;
@@ -82,6 +96,8 @@ typedef struct node_chain {
 
 typedef struct way_s {
   item_id_t id;
+  item_id_t version;
+  item_id_t changeset;
   user_t *user;
   gboolean visible;
   time_t time;
@@ -123,6 +139,8 @@ typedef struct way_chain {
 
 typedef struct relation_s {
   item_id_t id;
+  item_id_t version;
+  item_id_t changeset;
   user_t *user;
   gboolean visible;
   time_t time;
@@ -145,7 +163,6 @@ typedef struct relation_chain_s {
 /* the current hash table uses 16 bits. each table thus is */
 /* 256 kbytes (2^16 * sizeof(void*)) in size */
 #define ID2HASH(a) ((unsigned short)(a) ^ (unsigned short)((a)>>16))
-
 typedef struct hash_item_s {
   union {
     node_t *node;
@@ -164,18 +181,20 @@ typedef enum {
   ILLEGAL=0, NODE, WAY, RELATION, NODE_ID, WAY_ID, RELATION_ID
 } type_t;
 
-typedef struct member_s {
-  type_t type; 
-  char   *role;
-
+typedef struct {
+  type_t type;
   union {
     node_t *node;
     way_t *way;
     relation_t *relation;
-    void *ptr;
     item_id_t id;
+    void *ptr;
   };
+} object_t;
 
+typedef struct member_s {
+  object_t object;
+  char   *role;
   struct member_s *next;
 } member_t;
 
@@ -233,9 +252,11 @@ gboolean osm_is_creator_tag(tag_t *tag);
 gboolean osm_tag_key_and_value_present(tag_t *haystack, tag_t *tag);
 gboolean osm_tag_key_other_value_present(tag_t *haystack, tag_t *tag);
 
-char *osm_generate_xml_node(osm_t *osm, node_t *node);
-char *osm_generate_xml_way(osm_t *osm, way_t *way);
-char *osm_generate_xml_relation(osm_t *osm, relation_t *relation);
+char *osm_generate_xml_changeset(osm_t *osm, char *comment);
+char *osm_generate_xml_node(osm_t *osm, item_id_t changeset, node_t *node);
+char *osm_generate_xml_way(osm_t *osm, item_id_t changeset, way_t *way);
+char *osm_generate_xml_relation(osm_t *osm, item_id_t changeset, 
+				relation_t *relation);
 
 node_t *osm_get_node_by_id(osm_t *osm, item_id_t id);
 way_t *osm_get_way_by_id(osm_t *osm, item_id_t id);
@@ -262,7 +283,9 @@ gboolean osm_position_within_bounds(osm_t *osm, gint x, gint y);
 item_id_t osm_new_way_id(osm_t *osm);
 gboolean osm_way_ends_with_node(way_t *way, node_t *node);
 
-void osm_way_revert(way_t *way);
+void osm_way_reverse(way_t *way);
+guint osm_way_reverse_direction_sensitive_tags(way_t *way);
+guint osm_way_reverse_direction_sensitive_roles(osm_t *osm, way_t *way);
 
 void osm_node_remove_from_relation(osm_t *osm, node_t *node);
 void osm_way_remove_from_relation(osm_t *osm, way_t *way);
@@ -273,11 +296,6 @@ void osm_way_rotate(way_t *way, gint offset);
 
 tag_t *osm_tags_copy(tag_t *tag, gboolean update_creator);
 
-char *osm_type_string(type_t type);
-char *osm_id_string(type_t type, void *object);
-char *osm_object_string(type_t type, void *object);
-tag_t *osm_object_get_tags(type_t type, void *object);
-
 relation_t *osm_relation_new(void);
 void osm_relation_free(relation_t *relation);
 void osm_relation_attach(osm_t *osm, relation_t *relation);
@@ -285,6 +303,12 @@ void osm_relation_delete(osm_t *osm, relation_t *relation,
 			 gboolean permanently);
 gint osm_relation_members_num(relation_t *relation);
 
+char *osm_object_type_string(object_t *object);
+char *osm_object_id_string(object_t *object);
+char *osm_object_string(object_t *object);
+tag_t *osm_object_get_tags(object_t *object);
+void osm_object_set_flags(object_t *map_item, int set, int clr);
+
 #endif /* OSM_H */
 
 // vim:et:ts=8:sw=2:sts=2:ai
