@@ -73,19 +73,18 @@ typedef struct {
     GtkWidget *view;
   } log;
 
-#ifdef API06
   item_id_t changeset;
   char *comment;
-#endif
+
+  proxy_t *proxy;
 } osm_upload_context_t;
 
-gboolean osm_download(GtkWidget *parent, project_t *project) {
+gboolean osm_download(GtkWidget *parent, settings_t *settings,
+		      project_t *project) {
   printf("download osm ...\n");
 
-#ifdef API06
   g_assert(project->server);
 
-
   /* check if server name contains string "0.5" and adjust it */
   if(strstr(project->server, "0.5") != NULL) {
     strstr(project->server, "0.5")[2] = '6';
@@ -97,7 +96,6 @@ gboolean osm_download(GtkWidget *parent, project_t *project) {
     project->dirty = TRUE; // project needs to be changed 
   } else
     printf("url ok\n");
-#endif
 
   char minlon[G_ASCII_DTOSTR_BUF_SIZE], minlat[G_ASCII_DTOSTR_BUF_SIZE];
   char maxlon[G_ASCII_DTOSTR_BUF_SIZE], maxlat[G_ASCII_DTOSTR_BUF_SIZE];
@@ -117,7 +115,8 @@ gboolean osm_download(GtkWidget *parent, project_t *project) {
   char *url = g_strdup_printf("%s/map?bbox=%s,%s,%s,%s",
 		project->server, minlon, minlat, maxlon, maxlat);
 
-  gboolean result = net_io_download_file(parent, url, project->osm);
+  gboolean result = net_io_download_file(parent, settings, 
+					 url, project->osm);
 
   g_free(url);
   return result;
@@ -190,7 +189,8 @@ static void appendf(struct log_s *log, char *colname,
 #define MAX_TRY 5
 
 static gboolean osm_update_item(struct log_s *log, char *xml_str, 
-				char *url, char *user, item_id_t *id) {
+				char *url, char *user, item_id_t *id,
+				proxy_t *proxy) {
   int retry = MAX_TRY;
   char buffer[CURL_ERROR_SIZE];
 
@@ -253,6 +253,8 @@ static gboolean osm_update_item(struct log_s *log, char *xml_str,
     /* set user name and password for the authentication */
     curl_easy_setopt(curl, CURLOPT_USERPWD, user);
     
+    net_io_set_proxy(curl, proxy);
+
     /* Now run off and do what you've been told! */
     res = curl_easy_perform(curl);
     
@@ -281,14 +283,12 @@ static gboolean osm_update_item(struct log_s *log, char *xml_str,
       else    appendf(log, COLOR_OK, _("ok: #%ld\n"), *id);
     }
     
-#ifdef API06
     /* if it's neither "ok" (200), nor "internal server error" (500) */
     /* then write the message to the log */
     if((response != 200) && (response != 500) && write_data.ptr) {
       appendf(log, NULL, _("Server reply: "));
       appendf(log, COLOR_ERR, _("%s\n"), write_data.ptr);
     }
-#endif
 
     if(write_data.ptr)
       g_free(write_data.ptr);
@@ -304,18 +304,16 @@ static gboolean osm_update_item(struct log_s *log, char *xml_str,
 }
 
 static gboolean osm_delete_item(struct log_s *log, char *xml_str, 
-				char *url, char *user) {
+				char *url, char *user, proxy_t *proxy) {
   int retry = MAX_TRY;
   char buffer[CURL_ERROR_SIZE];
 
   CURL *curl;
   CURLcode res;
 
-#ifdef API06
   /* delete has a payload since api 0.6 */
   curl_data_t read_data;
   curl_data_t write_data;
-#endif
 
   while(retry >= 0) {
 
@@ -329,7 +327,6 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
       return FALSE;
     }
 
-#ifdef API06
     read_data.ptr = xml_str;
     read_data.len = xml_str?strlen(xml_str):0;
     write_data.ptr = NULL;
@@ -349,7 +346,6 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
 
     /* enable uploading */
     curl_easy_setopt(curl, CURLOPT_UPLOAD, 1L);
-#endif
 
     /* no read/write functions required */
     curl_easy_setopt(curl, CURLOPT_CUSTOMREQUEST, "DELETE"); 
@@ -373,6 +369,8 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
     /* set user name and password for the authentication */
     curl_easy_setopt(curl, CURLOPT_USERPWD, user);
     
+    net_io_set_proxy(curl, proxy);
+
     /* Now run off and do what you've been told! */
     res = curl_easy_perform(curl);
     
@@ -393,7 +391,6 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
     else
       appendf(log, COLOR_OK, _("ok\n"));
     
-#ifdef API06
     /* if it's neither "ok" (200), nor "internal server error" (500) */
     /* then write the message to the log */
     if((response != 200) && (response != 500) && write_data.ptr) {
@@ -403,7 +400,6 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
 
     if(write_data.ptr)
       g_free(write_data.ptr);
-#endif
 
     /* don't retry unless we had an "internal server error" */
     if(response != 500) 
@@ -462,15 +458,10 @@ static void osm_delete_nodes(osm_upload_context_t *context) {
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
 
-#ifdef API06
       char *xml_str =
 	osm_generate_xml_node(context->osm, context->changeset, node);
 
-      if(osm_delete_item(&context->log, xml_str, url, cred)) {
-#else
-      if(osm_delete_item(&context->log, NULL, url, cred)) {
-#endif
-
+      if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
 	node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
@@ -504,11 +495,7 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 
       /* upload this node */
       char *xml_str = 
-#ifndef API06
-	osm_generate_xml_node(context->osm, ILLEGAL, node);
-#else
 	osm_generate_xml_node(context->osm, context->changeset, node);
-#endif
       if(xml_str) {
 	printf("uploading node %s from address %p\n", url, xml_str);
 
@@ -516,7 +503,8 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-		   (node->flags & OSM_FLAG_NEW)?&(node->id):&(node->version))) {
+		   (node->flags & OSM_FLAG_NEW)?&(node->id):&(node->version),
+			   context->proxy)) {
 	  node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
@@ -547,14 +535,10 @@ static void osm_delete_ways(osm_upload_context_t *context) {
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
 
-#ifdef API06
       char *xml_str =
 	osm_generate_xml_way(context->osm, context->changeset, way);
 
-      if(osm_delete_item(&context->log, xml_str, url, cred)) {
-#else
-      if(osm_delete_item(&context->log, NULL, url, cred)) {
-#endif
+      if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
 	way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
@@ -589,11 +573,7 @@ static void osm_upload_ways(osm_upload_context_t *context) {
       
       /* upload this node */
       char *xml_str = 
-#ifndef API06
-	osm_generate_xml_way(context->osm, ILLEGAL, way);
-#else
 	osm_generate_xml_way(context->osm, context->changeset, way);
-#endif
       if(xml_str) {
 	printf("uploading way %s from address %p\n", url, xml_str);
 	
@@ -601,7 +581,8 @@ static void osm_upload_ways(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-		   (way->flags & OSM_FLAG_NEW)?&(way->id):&(way->version))) {
+		   (way->flags & OSM_FLAG_NEW)?&(way->id):&(way->version),
+			   context->proxy)) {
 	  way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
@@ -632,14 +613,10 @@ static void osm_delete_relations(osm_upload_context_t *context) {
 				   context->appdata->settings->username, 
 				   context->appdata->settings->password);
 
-#ifdef API06
       char *xml_str =
 	osm_generate_xml_relation(context->osm, context->changeset, relation);
 
-      if(osm_delete_item(&context->log, xml_str, url, cred)) {
-#else
-      if(osm_delete_item(&context->log, NULL, url, cred)) {
-#endif
+      if(osm_delete_item(&context->log, xml_str, url, cred, context->proxy)) {
 	relation->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
 	project->data_dirty = TRUE;
       }
@@ -675,11 +652,7 @@ static void osm_upload_relations(osm_upload_context_t *context) {
       
       /* upload this relation */
       char *xml_str =
-#ifndef API06
-	osm_generate_xml_relation(context->osm, ILLEGAL, relation);
-#else
 	osm_generate_xml_relation(context->osm, context->changeset, relation);
-#endif
       if(xml_str) {
 	printf("uploading relation %s from address %p\n", url, xml_str);
 	
@@ -687,7 +660,8 @@ static void osm_upload_relations(osm_upload_context_t *context) {
 				     context->appdata->settings->username, 
 				     context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
-	   (relation->flags & OSM_FLAG_NEW)?&(relation->id):&(relation->version))) {
+	   (relation->flags & OSM_FLAG_NEW)?&(relation->id):&(relation->version),
+			   context->proxy)) {
 	  relation->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
 	  project->data_dirty = TRUE;
 	}
@@ -699,7 +673,6 @@ static void osm_upload_relations(osm_upload_context_t *context) {
   }
 }
  
-#ifdef API06
 static gboolean osm_create_changeset(osm_upload_context_t *context) {
   gboolean result = FALSE;
   context->changeset = ILLEGAL;
@@ -721,7 +694,7 @@ static gboolean osm_create_changeset(osm_upload_context_t *context) {
 				 context->appdata->settings->password);
 
     if(osm_update_item(&context->log, xml_str, url, cred, 
-		       &context->changeset)) {
+		       &context->changeset, context->proxy)) {
       printf("got changeset id " ITEM_ID_FORMAT "\n", context->changeset);
       result = TRUE;
     }
@@ -750,7 +723,7 @@ static gboolean osm_close_changeset(osm_upload_context_t *context) {
 			       context->appdata->settings->username, 
 			       context->appdata->settings->password);
   
-  if(osm_update_item(&context->log, NULL, url, cred, NULL)) 
+  if(osm_update_item(&context->log, NULL, url, cred, NULL, context->proxy)) 
     result = TRUE;
   
   g_free(cred);
@@ -758,9 +731,7 @@ static gboolean osm_close_changeset(osm_upload_context_t *context) {
 
   return result;
 }
-#endif
 
-#ifdef API06
 /* comment buffer has been edited, allow upload if the buffer is not empty */
 static void callback_buffer_modified(GtkTextBuffer *buffer, GtkDialog *dialog) {
   GtkTextIter start, end;
@@ -770,7 +741,24 @@ static void callback_buffer_modified(GtkTextBuffer *buffer, GtkDialog *dialog) {
   gtk_dialog_set_response_sensitive(dialog, GTK_RESPONSE_ACCEPT, 
 				    text && strlen(text));
 }
-#endif
+
+static gboolean cb_focus_in(GtkTextView *view, GdkEventFocus *event,
+			     GtkTextBuffer *buffer) {
+
+  gboolean first_click = 
+    GPOINTER_TO_INT(g_object_get_data(G_OBJECT(view), "first_click"));
+
+  g_object_set_data(G_OBJECT(view), "first_click", GINT_TO_POINTER(FALSE));
+
+  if(first_click) {
+    GtkTextIter start, end;
+    gtk_text_buffer_get_start_iter(buffer, &start);
+    gtk_text_buffer_get_end_iter(buffer, &end);
+    gtk_text_buffer_delete(buffer, &start, &end);
+  }
+
+  return FALSE;
+}
 
 void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
 
@@ -876,7 +864,6 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   gtk_table_attach_defaults(GTK_TABLE(table),  pentry, 1, 2, 1, 2);
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), table);
 
-#ifdef API06
   GtkWidget *scrolled_win = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_win), 
   				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -899,12 +886,15 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   gtk_text_view_set_left_margin(GTK_TEXT_VIEW(view), 2 );
   gtk_text_view_set_right_margin(GTK_TEXT_VIEW(view), 2 );
 
+  g_object_set_data(G_OBJECT(view), "first_click", GINT_TO_POINTER(TRUE));
+  g_signal_connect(G_OBJECT(view), "focus-in-event",
+		   G_CALLBACK(cb_focus_in), buffer);
+ 
+
   gtk_container_add(GTK_CONTAINER(scrolled_win), view);
 
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), 
   			      scrolled_win);
-#endif
-
   gtk_widget_show_all(dialog);
 
   if(GTK_RESPONSE_ACCEPT != gtk_dialog_run(GTK_DIALOG(dialog))) {
@@ -932,14 +922,16 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   context->osm = osm;
   context->project = project;
 
-#ifdef API06
+  /* add proxy settings if required */
+  if(appdata->settings)
+    context->proxy = appdata->settings->proxy;
+
   /* fetch comment from dialog */
   GtkTextIter start, end;
   gtk_text_buffer_get_start_iter(buffer, &start);
   gtk_text_buffer_get_end_iter(buffer, &end);
   char *text = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
   if(text) context->comment = g_strdup(text);
-#endif
 
   gtk_widget_destroy(dialog);
   project_save(GTK_WIDGET(appdata->window), project);
@@ -980,10 +972,6 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     project->dirty = TRUE;  /* project needs to be saved */
   }
 
-#ifndef API06
-  appendf(&context->log, NULL, _("Log generated by %s v%s using API 0.5\n"), 
-	  PACKAGE, VERSION);
-#else
   appendf(&context->log, NULL, _("Log generated by %s v%s using API 0.6\n"), 
 	  PACKAGE, VERSION);
   appendf(&context->log, NULL, _("User comment: %s\n"), context->comment);
@@ -997,34 +985,28 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     appendf(&context->log, NULL, _("Adjusting server name to v0.6\n"));
     project->dirty = TRUE; // project needs to be changed 
   }
-#endif
 
   appendf(&context->log, NULL, _("Uploading to %s\n"), project->server);
 
-#ifdef API06
   /* create a new changeset */
   if(osm_create_changeset(context)) {
-#endif
-
-  /* check for dirty entries */
-  appendf(&context->log, NULL, _("Uploading nodes:\n"));
-  osm_upload_nodes(context);
-  appendf(&context->log, NULL, _("Uploading ways:\n"));
-  osm_upload_ways(context);
-  appendf(&context->log, NULL, _("Uploading relations:\n"));
-  osm_upload_relations(context);
-  appendf(&context->log, NULL, _("Deleting relations:\n"));
-  osm_delete_relations(context);
-  appendf(&context->log, NULL, _("Deleting ways:\n"));
-  osm_delete_ways(context);
-  appendf(&context->log, NULL, _("Deleting nodes:\n"));
-  osm_delete_nodes(context);
-
-#ifdef API06
-  /* close changeset */
-  osm_close_changeset(context);
+    /* check for dirty entries */
+    appendf(&context->log, NULL, _("Uploading nodes:\n"));
+    osm_upload_nodes(context);
+    appendf(&context->log, NULL, _("Uploading ways:\n"));
+    osm_upload_ways(context);
+    appendf(&context->log, NULL, _("Uploading relations:\n"));
+    osm_upload_relations(context);
+    appendf(&context->log, NULL, _("Deleting relations:\n"));
+    osm_delete_relations(context);
+    appendf(&context->log, NULL, _("Deleting ways:\n"));
+    osm_delete_ways(context);
+    appendf(&context->log, NULL, _("Deleting nodes:\n"));
+    osm_delete_nodes(context);
+    
+    /* close changeset */
+    osm_close_changeset(context);
   }
-#endif
 
   appendf(&context->log, NULL, _("Upload done.\n"));
 
@@ -1033,7 +1015,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
     appendf(&context->log, NULL, _("Server data has been modified.\n"));
     appendf(&context->log, NULL, _("Downloading updated osm data ...\n"));
 
-    if(osm_download(context->dialog, project)) {
+    if(osm_download(context->dialog, appdata->settings, project)) {
       appendf(&context->log, NULL, _("Download successful!\n"));
       appendf(&context->log, NULL, _("The map will be reloaded.\n"));
       project->data_dirty = FALSE;
@@ -1082,9 +1064,7 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   gtk_dialog_run(GTK_DIALOG(context->dialog));
   gtk_widget_destroy(context->dialog);
 
-#ifdef API06
   if(context->comment) g_free(context->comment);
-#endif
   g_free(context);
 }
 
