@@ -22,6 +22,8 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
+#define PROXY_KEY  "/system/http_proxy/"
+
 enum {
   STORE_STRING, STORE_FLOAT, STORE_INT, STORE_BOOL,
 };
@@ -205,6 +207,29 @@ settings_t *settings_load(void) {
     settings->wms_server = wms_server_get_default();
   }
 
+  /* ------------- get proxy settings -------------------- */
+  if(gconf_client_get_bool(client, PROXY_KEY "use_http_proxy", NULL)) {
+    proxy_t *proxy = settings->proxy = g_new0(proxy_t, 1);
+
+    /* get basic settings */
+    proxy->host = gconf_client_get_string(client, PROXY_KEY "host", NULL);
+    proxy->port = gconf_client_get_int(client, PROXY_KEY "port", NULL);
+    proxy->ignore_hosts = 
+      gconf_client_get_string(client, PROXY_KEY "ignore_hosts", NULL);
+
+    /* check for authentication */
+    proxy->use_authentication = 
+      gconf_client_get_bool(client, PROXY_KEY "use_authentication", NULL);
+    
+    if(proxy->use_authentication) {
+      proxy->authentication_user = 
+	gconf_client_get_string(client, PROXY_KEY "authentication_user", NULL);
+      proxy->authentication_password = 
+	gconf_client_get_string(client, PROXY_KEY "authentication_password", 
+				NULL);
+    }
+  }
+
   return settings;
 }
 
@@ -285,5 +310,17 @@ void settings_free(settings_t *settings) {
     st++;
   }
 
+  /* free proxy settings if present */
+  if(settings->proxy) {
+    proxy_t *proxy = settings->proxy;
+
+    if(proxy->host)                    g_free(proxy->host);
+    if(proxy->ignore_hosts)            g_free(proxy->ignore_hosts);
+    if(proxy->authentication_user)     g_free(proxy->authentication_user);
+    if(proxy->authentication_password) g_free(proxy->authentication_password);
+
+    g_free(proxy);
+  }
+
   g_free(settings);
 }
