@@ -37,7 +37,13 @@
 #ifndef USE_HILDON
 #define BASE_DIR ".osm2go/"
 #else
+#if MAEMO_VERSION_MAJOR < 4 
+/* use internal memory card on old units */
 #define BASE_DIR "/media/mmc2/osm2go/"
+#else
+/* use new location of memory card on new devices */
+#define BASE_DIR "/home/user/MyDocs/.osm2go/"
+#endif
 #endif
 
 #define DEFAULT_STYLE "mapnik"
